@@ -27,18 +27,20 @@ estimators <- function(object, ...) UseMethod("estimators")
 #' @param indicator optional character vector that selects which indicators
 #' shall be returned: (i) all calculated indicators ("all");
 #' (ii) each indicator name: "Mean" "Quantile_10", "Quantile_25", "Median",
-#' "Quantile_75", "Quantile_90", "Head_Count", "Poverty_Gap", "Gini", 
-#' "Quintile_Share" or the function name/s of "custom_indicator/s"; 
-#' (iii) groups of indicators: "Quantiles", "Poverty", "Inequality" or "Custom". 
-#' Defaults to "all". Note, additional custom indicators can be 
+#' "Quantile_75", "Quantile_90", "Head_Count", 
+#' "Poverty_Gap", "Gini", "Quintile_Share" or the function name/s of 
+#' "custom_indicator/s"; (iii) groups of indicators: "Quantiles", "Poverty", 
+#' "Inequality" or "Custom".If two of these groups are selected, only the first
+#' one is returned. Defaults to "all". Note, additional custom indicators can be 
 #' defined as argument for model-based approaches (see also \code{\link{ebp}}) 
 #' and do not appear in groups of indicators even though these might belong to 
 #' one of the groups.  
-#' @param MSE optional logical. If TRUE, MSE estimates for selected indicators
-#' per domain are added to the data frame of point estimates. Defaults to FALSE.
-#' @param CV optional logical. If TRUE, coefficients of variation for selected
+#' @param MSE optional logical. If \code{TRUE}, MSE estimates for selected indicators
+#' per domain are added to the data frame of point estimates. Defaults to 
+#' \code{FALSE}.
+#' @param CV optional logical. If \code{TRUE}, coefficients of variation for selected
 #' indicators per domain are added to the data frame of point estimates.
-#' Defaults to FALSE.
+#' Defaults to \code{FALSE}.
 #' @param ... other parameters that can be passed to function \code{estimators}.
 #' @return
 #' an object of type "estimators.emdi" with point and/or MSE
@@ -59,41 +61,35 @@ estimators <- function(object, ...) UseMethod("estimators")
 #' fam_allow + house_allow + cap_inv + tax_adj, pop_data = eusilcA_pop,
 #' pop_domains = "district", smp_data = eusilcA_smp, smp_domains = "district",
 #' threshold = 11064.82, transformation = "box.cox", 
-#' L= 50, MSE = TRUE, B = 50, custom_indicator = 
+#' L = 50, MSE = TRUE, B = 50, custom_indicator = 
 #' list( my_max = function(y, threshold){max(y)},
 #' my_min = function(y, threshold){min(y)}), na.rm = TRUE, cpus = 1)
-#'
-#' # choose Gini coefficient and MSE and CV
+#' 
+#' # Example 1: Choose Gini coefficient and MSE and CV
 #' estimators(emdi_model, indicator = "Gini", MSE = TRUE, CV = TRUE)
 #' 
-#' # choose custom indicators without MSE and CV
+#' # Example 2: Choose custom indicators without MSE and CV
 #' estimators(emdi_model, indicator = "Custom")
 #' }
 #' @export
 
 estimators.emdi <- function(object, indicator = "all", MSE = FALSE, CV = FALSE, ...) {
 
-  if(!any(class(object)=="emdi")){
-    stop('First object needs to be of class emdi.')
-  }
-  
-  if (is.null(object$MSE) && (MSE == TRUE || CV == TRUE)){
-    stop('No MSE estimates in object: arguments MSE and CV have to be FALSE')
-  }
+  estimators_check(object = object, indicator = indicator, 
+                   MSE = MSE, CV = CV)
   
   # Only point estimates
   all_ind <- point_emdi(object = object, indicator = indicator)
   selected <- colnames(all_ind$ind)[-1]
 
-  if( MSE == TRUE || CV ==TRUE )
-  {
+  if ( MSE == TRUE || CV == TRUE ) {
     all_precisions <- mse_emdi(object = object, indicator = indicator, CV = TRUE)
     colnames(all_precisions$ind) <- paste0(colnames(all_precisions$ind), "_MSE")
     colnames(all_precisions$ind_cv) <- paste0(colnames(all_precisions$ind_cv), "_CV")
     combined <- data.frame(all_ind$ind, all_precisions$ind, all_precisions$ind_cv)
     endings <- c("","_MSE", "_CV")[c(TRUE,MSE,CV)]
 
-    combined <- combined[,c("Domain",paste0(rep(selected,each=length(endings)),
+    combined <- combined[,c("Domain",paste0(rep(selected,each = length(endings)),
                                            endings))]
   } else {
     combined <- all_ind$ind
@@ -147,7 +143,7 @@ print.estimators.emdi <- function(x,...) {
 #' smp_data = eusilcA_smp, smp_domains = "district",
 #' na.rm = TRUE)
 #'
-#' # choose first lines of the Gini coefficient, MSE and CV
+#' # Example: Choose first lines of the Gini coefficient, MSE and CV
 #' head(estimators(emdi_model, indicator = c("Gini", "Head_Count")))
 #' }
 #' @importFrom utils head
@@ -176,14 +172,14 @@ head.estimators.emdi <- function(x, n = 6L, addrownums=NULL, ...) {
 #' data("eusilcA_smp")
 #' 
 #' # generate emdi object with deleting missing values; here via function ebp()
-#' set.seed(100); emdi_model <- ebp( fixed = eqIncome ~ gender + eqsize + cash + 
+#' emdi_model <- ebp( fixed = eqIncome ~ gender + eqsize + cash + 
 #' self_empl + unempl_ben + age_ben + surv_ben + sick_ben + dis_ben + rent + 
 #' fam_allow + house_allow + cap_inv + tax_adj,
 #' pop_data = eusilcA_pop, pop_domains = "district",
 #' smp_data = eusilcA_smp, smp_domains = "district",
 #' na.rm = TRUE)
 #'
-#' # choose last lines of the Gini coefficient, MSE and CV
+#' # Example: Choose last lines of the Gini coefficient, MSE and CV
 #' tail(estimators(emdi_model, indicator = c("Gini", "Head_Count")))
 #' }
 #' @importFrom utils tail
@@ -227,14 +223,14 @@ as.data.frame.estimators.emdi <- function(x,...) {
 #' data("eusilcA_smp")
 #' 
 #' # generate emdi object with deleting missing values; here via function ebp()
-#' set.seed(100); emdi_model <- ebp( fixed = eqIncome ~ gender + eqsize + cash + 
+#' emdi_model <- ebp( fixed = eqIncome ~ gender + eqsize + cash + 
 #' self_empl + unempl_ben + age_ben + surv_ben + sick_ben + dis_ben + rent + 
 #' fam_allow + house_allow + cap_inv + tax_adj,
 #' pop_data = eusilcA_pop, pop_domains = "district",
 #' smp_data = eusilcA_smp, smp_domains = "district",
 #' na.rm = TRUE)
 #'
-#' # choose last lines of the Gini coefficient, MSE and CV
+#' # Example: Choose last lines of the Gini coefficient, MSE and CV
 #' subset(estimators(emdi_model, indicator = "Gini"), 
 #'        Domain %in% c("Wien", "Wien Umgebung"))
 #' }
