@@ -1,10 +1,11 @@
 
 mse_emdi <- function(object, indicator = "all", CV = FALSE) {
 
-  if (is.null(object$MSE)) {
-    stop('No MSE estimates in object: method mse not applicable')
+  if (is.null(object$MSE) && CV == TRUE) {
+    stop('No MSE estimates in emdi object: arguments MSE and CV have to be FALSE
+          or a new emdi object with variance/MSE needs to be generated.')
   }
-  if((ncol(object$ind)==11) && any(indicator=="Custom"||indicator=="custom")){
+  if ((ncol(object$ind) == 11) && any(indicator == "Custom" || indicator == "custom")) {
     stop('No individual indicators are defined. Either select other indicators or
          define custom indicators and generate a new emdi object. See also help(ebp).')
   }
@@ -12,20 +13,17 @@ mse_emdi <- function(object, indicator = "all", CV = FALSE) {
   # Calculation of CVs
   all_cv <- sqrt(object$MSE[,-1]) / object$ind[,-1]
 
-  if(any(indicator == "Quantiles")||any(indicator == "quantiles"))
-  {
-    indicator = c(indicator[!(indicator == "Quantiles"||indicator == "quantiles")], "Quantile_10", "Quantile_25", "Median", "Quantile_75", "Quantile_90")
+  if (any(indicator == "Quantiles") || any(indicator == "quantiles")) {
+    indicator = c(indicator[!(indicator == "Quantiles" || indicator == "quantiles")], "Quantile_10", "Quantile_25", "Median", "Quantile_75", "Quantile_90")
   }
-  if(any(indicator == "poverty")||any(indicator == "Poverty"))
-  {
-    indicator = c(indicator[!(indicator == "poverty"||indicator == "Poverty")], "Head_Count", "Poverty_Gap")
+  if (any(indicator == "poverty") || any(indicator == "Poverty")) {
+    indicator = c(indicator[!(indicator == "poverty" || indicator == "Poverty")], "Head_Count", "Poverty_Gap")
   }
-  if(any(indicator == "inequality")||any(indicator == "Inequality"))
-  {
-    indicator = c(indicator[!(indicator == "inequality"||indicator == "Inequality")], "Gini", "Quintile_Share")
+  if (any(indicator == "inequality") || any(indicator == "Inequality")) {
+    indicator = c(indicator[!(indicator == "inequality" || indicator == "Inequality")], "Gini", "Quintile_Share")
   }
-  if(any(indicator == "custom")||any(indicator == "Custom")){
-     indicator = c(indicator[!(indicator == "custom"||indicator == "Custom")],
+  if (any(indicator == "custom") || any(indicator == "Custom")) {
+     indicator = c(indicator[!(indicator == "custom" || indicator == "Custom")],
                    colnames(object$ind[-c(1,2,3,4,5,6,7,8,9,10,11)]))
   }
 
