@@ -10,19 +10,19 @@
 #' @param indicator optional character vector that selects which indicators
 #' shall be returned: (i) all calculated indicators ("all");
 #' (ii) each indicator name: "Mean" "Quantile_10", "Quantile_25", "Median",
-#' "Quantile_75", "Quantile_90", "Head_Count", "Poverty_Gap", "Gini", 
-#' "Quintile_Share" or the function name/s of "custom_indicator/s"; 
-#' (iii) groups of indicators: "Quantiles", "Poverty" or 
+#' "Quantile_75", "Quantile_90", "Head_Count", 
+#' "Poverty_Gap", "Gini", "Quintile_Share" or the function name/s of 
+#' "custom_indicator/s"; (iii) groups of indicators: "Quantiles", "Poverty" or 
 #' "Inequality". Defaults to "all". Note, additional custom indicators can be 
 #' defined as argument for model-based approaches (see also \code{\link{ebp}}) 
 #' and do not appear in groups of indicators even though these might belong to 
 #' one of the groups.  
-#' @param MSE logical. If TRUE, the MSE of the emdiObject is exported. Defaults 
-#' to \code{FALSE}.
-#' @param CV logical. If TRUE, the CV of the emdiObject is exported. Defaults 
-#' to \code{FALSE}.
-#' @param split logical. If TRUE, point estimates, MSE and CV are written to
-#' different sheets in the excel file. Defaults to \code{FALSE}.
+#' @param MSE logical. If \code{TRUE}, the MSE of the emdiObject is exported. 
+#' Defaults to \code{FALSE}.
+#' @param CV logical. If \code{TRUE}, the CV of the emdiObject is exported. 
+#' Defaults to \code{FALSE}.
+#' @param split logical. If \code{TRUE}, point estimates, MSE and CV are written 
+#' to different sheets in the excel file. Defaults to \code{FALSE}.
 #' @return An excel file is created in your working directory, or at the given
 #' path.
 #' @details This function creates an excel file via the package
@@ -45,23 +45,23 @@
 #' data("eusilcA_pop")
 #' data("eusilcA_smp")
 #' 
-#' # Example with two additional indicators
+#' # Generate emdi object with two additional indicators
 #' emdi_model <- ebp(fixed = eqIncome ~ gender + eqsize + cash + 
 #' self_empl + unempl_ben + age_ben + surv_ben + sick_ben + dis_ben + rent + 
 #' fam_allow + house_allow + cap_inv + tax_adj, pop_data = eusilcA_pop,
 #' pop_domains = "district", smp_data = eusilcA_smp, smp_domains = "district",
-#' threshold = function(y){0.6 * median(y)}, L= 50, MSE = TRUE, B = 50, 
+#' threshold = function(y){0.6 * median(y)}, L = 50, MSE = TRUE, B = 50, 
 #' custom_indicator = list( my_max = function(y, threshold){max(y)},
 #' my_min = function(y, threshold){min(y)}), na.rm = TRUE, cpus = 1)
 #' 
-#' # Export estimates for all indicators and uncertainty measures and 
+#' # Example 1: Export estimates for all indicators and uncertainty measures and 
 #' # diagnostics to excel
-#' write.excel(emdi_model, file ="excel_output_all.xlsx", indicator = "all", 
+#' write.excel(emdi_model, file = "excel_output_all.xlsx", indicator = "all", 
 #' MSE = TRUE, CV = TRUE)
 #' 
-#' # Single excel sheets for point, MSE and CV estimates
-#' write.excel(emdi_model, file ="excel_output_all_split.xlsx", indicator = "all", 
-#' MSE = TRUE, CV = TRUE, split=TRUE)
+#' # Example 2: Single excel sheets for point, MSE and CV estimates
+#' write.excel(emdi_model, file = "excel_output_all_split.xlsx", indicator = "all", 
+#' MSE = TRUE, CV = TRUE, split = TRUE)
 #' }
 #' @export
 #' @import openxlsx
@@ -72,6 +72,11 @@ write.excel <- function(object,
                         MSE       = FALSE,
                         CV        = FALSE,
                         split     = FALSE) {
+  
+  writeexcel_check(object = object, 
+                   file = file, 
+                   split = split)
+  
   wb <- createWorkbook()
 
   headlines_cs <- createStyle(fontColour     = "#ffffff",
@@ -84,14 +89,12 @@ write.excel <- function(object,
                               #bgFill        = "#FFFFFF"
                               )
   
-  if("direct" %in% class(object))
-  {
+  if (inherits(object, "direct"))  {
     wb <- add_summary_direct(object = object, 
                              wb = wb, 
                              headlines_cs = headlines_cs)
   }
-  else if("model" %in% class(object))
-  {
+  else if (inherits(object, "model"))  {
     wb <- add_summary(object = object, wb = wb, headlines_cs = headlines_cs)
   }
 
@@ -109,7 +112,7 @@ write.excel <- function(object,
                         indicator    = indicator,
                         headlines_cs = headlines_cs
                         )
-    if(MSE || CV) {
+    if (MSE || CV) {
       wb <- add_precisions(object = object,
                            indicator = indicator,
                            MSE = MSE,
@@ -127,7 +130,7 @@ add_summary <- function(object, wb, headlines_cs) {
 
   title_cs <- createStyle(fontSize = 14,
                           border = "Bottom",
-                          halign ="left",
+                          halign = "left",
                           borderStyle = "thick",
                           textDecoration = "bold")
 
@@ -144,15 +147,15 @@ add_summary <- function(object, wb, headlines_cs) {
   addWorksheet(wb, sheetName = "summary", gridLines = FALSE)
 
   writeData(wb = wb, sheet = "summary", x = "Empirical Best Prediction", colNames = FALSE)
-  addStyle(wb = wb, sheet = "summary", cols = 1, rows = 1, style = title_cs, stack =TRUE)
+  addStyle(wb = wb, sheet = "summary", cols = 1, rows = 1, style = title_cs, stack = TRUE)
 
   starting_row <- 5
   writeDataTable(x = df_nobs,
                  withFilter = FALSE,
                  wb = wb,
                  sheet = "summary",
-                 startRow=starting_row,
-                 startCol=3,
+                 startRow = starting_row,
+                 startCol = 3,
                  rowNames = TRUE,
                  headerStyle = headlines_cs,
                  colNames = TRUE,
@@ -165,8 +168,8 @@ add_summary <- function(object, wb, headlines_cs) {
                  wb = wb,
                  withFilter = FALSE,
                  sheet = "summary",
-                 startRow=starting_row,
-                 startCol=3,
+                 startRow = starting_row,
+                 startCol = 3,
                  rowNames = TRUE,
                  headerStyle = headlines_cs,
                  colNames = TRUE,
@@ -176,14 +179,14 @@ add_summary <- function(object, wb, headlines_cs) {
   starting_row <- starting_row + 2 + nrow(df_size_dom)
 
   
-  if(!is.null(su$transform)){
+  if (!is.null(su$transform)) {
     
     writeDataTable(x = su$transform,
                    wb = wb,
                    withFilter = FALSE,
                    sheet = "summary",
-                   startRow=starting_row,
-                   startCol=3,
+                   startRow = starting_row,
+                   startCol = 3,
                    rowNames = FALSE,
                    headerStyle = headlines_cs,
                    colNames = TRUE,
@@ -198,8 +201,8 @@ add_summary <- function(object, wb, headlines_cs) {
                  wb = wb,
                  withFilter = FALSE,
                  sheet = "summary",
-                 startRow=starting_row,
-                 startCol=3,
+                 startRow = starting_row,
+                 startCol = 3,
                  rowNames = TRUE,
                  headerStyle = headlines_cs,
                  colNames = TRUE,
@@ -210,8 +213,8 @@ add_summary <- function(object, wb, headlines_cs) {
                  wb = wb,
                  withFilter = FALSE,
                  sheet = "summary",
-                 startRow=starting_row,
-                 startCol=4,
+                 startRow = starting_row,
+                 startCol = 4,
                  rowNames = FALSE,
                  headerStyle = headlines_cs,
                  colNames = TRUE,
@@ -232,7 +235,7 @@ add_summary_direct <- function(object, wb, headlines_cs) {
   
   title_cs <- createStyle(fontSize = 14,
                           border = "Bottom",
-                          halign ="left",
+                          halign = "left",
                           borderStyle = "thick",
                           textDecoration = "bold")
 
@@ -244,15 +247,15 @@ add_summary_direct <- function(object, wb, headlines_cs) {
   addWorksheet(wb, sheetName = "summary", gridLines = FALSE)
   
   writeData(wb = wb, sheet = "summary", x = "Direct Estimation", colNames = FALSE)
-  addStyle(wb = wb, sheet = "summary", cols = 1, rows = 1, style = title_cs, stack =TRUE)
+  addStyle(wb = wb, sheet = "summary", cols = 1, rows = 1, style = title_cs, stack = TRUE)
   
   starting_row <- 5
   writeDataTable(x = df_nobs,
                  withFilter = FALSE,
                  wb = wb,
                  sheet = "summary",
-                 startRow=starting_row,
-                 startCol=3,
+                 startRow = starting_row,
+                 startCol = 3,
                  rowNames = TRUE,
                  headerStyle = headlines_cs,
                  colNames = TRUE,
@@ -265,8 +268,8 @@ add_summary_direct <- function(object, wb, headlines_cs) {
                  wb = wb,
                  withFilter = FALSE,
                  sheet = "summary",
-                 startRow=starting_row,
-                 startCol=3,
+                 startRow = starting_row,
+                 startCol = 3,
                  rowNames = TRUE,
                  headerStyle = headlines_cs,
                  colNames = TRUE,
@@ -281,8 +284,8 @@ add_summary_direct <- function(object, wb, headlines_cs) {
                  wb = wb,
                  withFilter = FALSE,
                  sheet = "summary",
-                 startRow=starting_row,
-                 startCol=3,
+                 startRow = starting_row,
+                 startCol = 3,
                  rowNames = FALSE,
                  headerStyle = headlines_cs,
                  colNames = TRUE,
@@ -301,6 +304,18 @@ add_summary_direct <- function(object, wb, headlines_cs) {
 
 add_pointests <- function(object, indicator, wb, headlines_cs) {
   addWorksheet(wb, sheetName = "Point Estimators", gridLines = FALSE)
+  
+  if (is.null(indicator) || !(indicator == "all" || indicator == "Quantiles" 
+                              || indicator == "quantiles"
+                              || indicator == "Poverty" || indicator == "poverty" 
+                              || indicator == "Inequality" || indicator == "inequality" 
+                              || indicator == "Custom" || indicator == "custom" 
+                              || indicator %in% names(object$ind[-1]))) {
+    stop(paste0("The argument indicator is set to ", indicator, ". The argument 
+         only allows to be set to all, a name of estimated indicators or 
+                indicator groups as described in help(estimators.emdi)."))
+  }
+  
   data <- point_emdi(object = object, indicator = indicator)$ind
 
   writeDataTable(x           = data,
@@ -331,7 +346,7 @@ add_pointests <- function(object, indicator, wb, headlines_cs) {
 add_precisions <- function(object, indicator, MSE, wb, headlines_cs, CV) {
   precisions <- mse_emdi(object = object, indicator = indicator, CV = TRUE)
 
-  if(MSE) {
+  if (MSE) {
     addWorksheet(wb, sheetName = "MSE Estimators", gridLines = FALSE)
 
     writeDataTable(x           = precisions$ind,
@@ -355,7 +370,7 @@ add_precisions <- function(object, indicator, MSE, wb, headlines_cs, CV) {
                firstCol = TRUE
                )
   }
-  if(CV) {
+  if (CV) {
     addWorksheet(wb, sheetName = "CV Estimators", gridLines = FALSE)
 
     writeDataTable(precisions$ind_cv,
